Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
lmcat\__init__.py | 2 | 0 | 0 | 100%
lmcat\__main__.py | 3 | 3 | 0 | 0%
lmcat\file_stats.py | 42 | 7 | 0 | 83%
lmcat\lmcat.py | 188 | 51 | 0 | 73%
lmcat\processing_pipeline.py | 71 | 12 | 0 | 83%
lmcat\processors.py | 82 | 51 | 0 | 38%
tests\_temp\plugins_test\test_plugin.py | 8 | 0 | 0 | 100%
tests\test_lmcat.py | 193 | 11 | 0 | 94%
tests\test_lmcat_2.py | 87 | 23 | 0 | 74%
tests\test_lmcat_3.py | 99 | 2 | 0 | 98%
Total | 775 | 160 | 0 | 79%

No items found using the specified filter.